"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _NativeWindowIntegrationConnection_client, _NativeWindowIntegrationConnection_url;
Object.defineProperty(exports, "__esModule", { value: true });
exports.NativeWindowIntegrationConnection = void 0;
const mock_1 = require("openfin-adapter/src/mock");
const constants_1 = require("./constants");
const MockClient_1 = require("./MockClient");
/**
 * Class which represents a connection to the Native Window Integration Provider.
 * Exposes the basic "fragment" methods along with "connect".
 *
 * @param {OpenFin.ChannelClient} client - OpenFin channel client
 * @param {string} url
 * @exports
 * @class NativeWindowIntegrationConnection
 */
class NativeWindowIntegrationConnection {
    constructor(providerId, authorizedUuid, mockConnection, isLocal, rescueOnDisplayChange, url) {
        this.providerId = providerId;
        this.authorizedUuid = authorizedUuid;
        this.mockConnection = mockConnection;
        this.isLocal = isLocal;
        this.rescueOnDisplayChange = rescueOnDisplayChange;
        _NativeWindowIntegrationConnection_client.set(this, void 0);
        _NativeWindowIntegrationConnection_url.set(this, void 0);
        __classPrivateFieldSet(this, _NativeWindowIntegrationConnection_url, url, "f");
        __classPrivateFieldSet(this, _NativeWindowIntegrationConnection_client, null, "f");
    }
    get client() {
        if (!__classPrivateFieldGet(this, _NativeWindowIntegrationConnection_client, "f")) {
            // no reconnect for now
            // const clientPromise = this.connect();
            throw new Error('The Native Window Integration Provider is not connected');
        }
        return __classPrivateFieldGet(this, _NativeWindowIntegrationConnection_client, "f");
    }
    async connect() {
        const client = await this.waitForConnection();
        client.onDisconnection(() => {
            __classPrivateFieldSet(this, _NativeWindowIntegrationConnection_client, null, "f");
        });
        __classPrivateFieldSet(this, _NativeWindowIntegrationConnection_client, client, "f");
        return;
    }
    async waitForConnection() {
        if (this.mockConnection) {
            return new MockClient_1.MockClient();
        }
        await this.launchIfNeeded();
        return mock_1.fin.InterApplicationBus.Channel.connect(this.providerId, {
            payload: {
                libVersion: constants_1.VERSION,
            },
        });
    }
    async launchIfNeeded() {
        if (this.isLocal) {
            return;
        }
        const isWindows = window.navigator.appVersion.indexOf('Win') !== -1;
        if (!isWindows) {
            throw new Error('Native Window Integration is only supported on Windows');
        }
        const { port, version: runtimeVersion, } = await mock_1.fin.System.getRuntimeInfo();
        const launchArguments = {
            alias: constants_1.DEFAULT_ALIAS,
            version: constants_1.VERSION,
            target: 'Openfin.NWI.Provider.exe',
            lifetime: 'application',
            arguments: `--port=${port} --channel-name=${this.providerId} --runtime-version=${runtimeVersion} --connection-uuid=${this.authorizedUuid} ${this.rescueOnDisplayChange ? '--rescue-on-display-change' : ''}`,
        };
        await mock_1.fin.System.downloadAsset({
            src: new URL(__classPrivateFieldGet(this, _NativeWindowIntegrationConnection_url, "f"), location.href).toString(),
            ...launchArguments,
        }, () => null);
        await mock_1.fin.System.launchExternalProcess(launchArguments);
        return;
    }
    async getSnapshotFragment() {
        return this.client.dispatch('get:snapshot:fragment');
    }
    async applySnapshotFragment(snapshotFragment, monitorInfo) {
        const payload = {
            configurations: (snapshotFragment === null || snapshotFragment === void 0 ? void 0 : snapshotFragment.configurations) || {},
            monitorInfo
        };
        console.log(payload);
        return this.client.dispatch('apply:snapshot:fragment', payload);
    }
}
exports.NativeWindowIntegrationConnection = NativeWindowIntegrationConnection;
_NativeWindowIntegrationConnection_client = new WeakMap(), _NativeWindowIntegrationConnection_url = new WeakMap();
//# sourceMappingURL=connection.js.map