interface ConfigLaunchInfo {
    path?: string;
    alias?: string;
    target?: string;
    lifetime?: 'window' | 'application' | 'persist' | string;
    arguments?: string;
}
export interface ConfigFragment {
    name: string;
    title: string;
    launch: ConfigLaunchInfo;
}
export declare type ClientConfiguration = ConfigFragment[];
interface ClientOptions {
    mockConnection?: boolean;
    local?: boolean;
    url: string;
    configuration: ClientConfiguration;
    rescueOnDisplayChange?: boolean;
}
export interface ErrorOrValue<T> {
    hasError: boolean;
    value: T;
    errorCode?: number;
    errorMessage?: string;
}
interface NativeApplicationProcessMetaData {
    CommandLineArguments: {
        Arguments: string;
        ImagePath: string;
        OriginalLineArguments: string;
    };
    ImageName: string;
    Injected: boolean;
}
interface NativeApplicationProcessInfo {
    CommandLineArgs: string | null;
    FilePath: string;
    MachineName: string;
    MainWindowHandle: {
        value: string;
    };
    ModuleName: string;
    StartTime: string;
}
interface NativeApplicationMetaData {
    alwaysOnTop: ErrorOrValue<boolean>;
    bounds: ErrorOrValue<OpenFin.Rectangle>;
    className: string;
    configurationName: string;
    focused: ErrorOrValue<boolean>;
    maximized: ErrorOrValue<boolean>;
    minimized: ErrorOrValue<boolean>;
    name: string;
    nativeId: string;
    process: ErrorOrValue<NativeApplicationProcessMetaData>;
    title: string;
    visible: ErrorOrValue<boolean>;
    zOrder: ErrorOrValue<boolean>;
}
export interface NativeWindowFragmentGet {
    config: {
        launch: {
            Path: string | null;
            Arguments: string;
        };
        name: string;
        title: string;
    };
    info: NativeApplicationMetaData[];
}
export interface NativeWindowFragmentApply {
    ApplicationMetaData: NativeApplicationMetaData;
    Process: NativeApplicationProcessInfo;
}
export interface NativeWindowConfigurations {
    configurations: NativeWindowFragmentGet[];
}
export declare type SnapshotWithFragment = OpenFin.Snapshot & {
    nativeWindows?: NativeWindowConfigurations;
};
/**
 * This class represents the Native Window Integration Client.
 * It has three methods: `create`, `decorateSnapshot` and `applySnapshot`
 *
 * @param {NativeWindowIntegrationConnection} client - connection to the provider
 * @param {ClientConfiguration} configuration - list of native applications
 * @exports
 * @class NativeWindowIntegrationClient
 */
export declare class NativeWindowIntegrationClient {
    #private;
    private constructor();
    static create(options: ClientOptions): Promise<NativeWindowIntegrationClient>;
    /**
     * Gets the current state of native application windows and
     * appends them to a snapshot as `nativeWindows`.
     *
     * @param {OpenFin.Snapshot} snapshot - Platform API `snapshot`.
     *
     * Which native windows get captured is determined by `System.enableNativeWindowIntegrationProvider`.
     */
    decorateSnapshot: <T extends {}>(snapshot: T) => Promise<T & {
        nativeWindows: NativeWindowConfigurations;
    }>;
    /**
     * Restores a `snapshot`'s `nativeWindows`.
     *
     * @param {OpenFin.Snapshot} snapshot - Platform API `snapshot`.
     */
    applySnapshot: (snapshot: SnapshotWithFragment) => Promise<ErrorOrValue<NativeWindowFragmentApply>[] | [
    ]>;
}
export {};
