"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _NativeWindowIntegrationClient_client, _NativeWindowIntegrationClient_configuration;
Object.defineProperty(exports, "__esModule", { value: true });
exports.NativeWindowIntegrationClient = void 0;
const mock_1 = require("openfin-adapter/src/mock");
const connection_1 = require("./connection");
// Typescript does not support truly private static class members so using a module scoped variable instead
let calledThroughCreate = false;
/**
 * This class represents the Native Window Integration Client.
 * It has three methods: `create`, `decorateSnapshot` and `applySnapshot`
 *
 * @param {NativeWindowIntegrationConnection} client - connection to the provider
 * @param {ClientConfiguration} configuration - list of native applications
 * @exports
 * @class NativeWindowIntegrationClient
 */
class NativeWindowIntegrationClient {
    constructor(client, configuration) {
        _NativeWindowIntegrationClient_client.set(this, void 0);
        _NativeWindowIntegrationClient_configuration.set(this, void 0);
        /**
         * Gets the current state of native application windows and
         * appends them to a snapshot as `nativeWindows`.
         *
         * @param {OpenFin.Snapshot} snapshot - Platform API `snapshot`.
         *
         * Which native windows get captured is determined by `System.enableNativeWindowIntegrationProvider`.
         */
        this.decorateSnapshot = async (snapshot) => {
            if (!snapshot || typeof snapshot !== 'object') {
                throw new Error('Must pass in an object to decorateSnapshot.');
            }
            const nativeWindows = await __classPrivateFieldGet(this, _NativeWindowIntegrationClient_client, "f").getSnapshotFragment();
            return { ...snapshot, nativeWindows };
        };
        /**
         * Restores a `snapshot`'s `nativeWindows`.
         *
         * @param {OpenFin.Snapshot} snapshot - Platform API `snapshot`.
         */
        this.applySnapshot = async (snapshot) => {
            var _a;
            if (snapshot.nativeWindows) {
                return __classPrivateFieldGet(this, _NativeWindowIntegrationClient_client, "f").applySnapshotFragment(snapshot.nativeWindows, (_a = snapshot.snapshotDetails) === null || _a === void 0 ? void 0 : _a.monitorInfo);
            }
            return [];
        };
        __classPrivateFieldSet(this, _NativeWindowIntegrationClient_client, client, "f");
        __classPrivateFieldSet(this, _NativeWindowIntegrationClient_configuration, configuration, "f");
        if (!calledThroughCreate) {
            throw new Error('Do not call the NativeWindowIntegrationClient constructor directly, use NativeWindowIntegrationClient.create instead.');
        }
    }
    static async create(options) {
        var _a, _b, _c;
        // eslint-disable-next-line no-useless-catch
        try {
            const { authorizedUuid, } = await mock_1.fin.System.enableNativeWindowIntegrationProvider(options.configuration);
            const providerId = options.local
                ? 'nwi:snapshot:provider'
                : `nwi:snapshot:provider:${authorizedUuid}`;
            if (options.local) {
                console.warn('Using the local option is not recommended');
                console.log('Authorized UUID (Change launchSettings.json):');
                console.log(authorizedUuid);
                mock_1.fin.me.isWindow && mock_1.fin.me.showDeveloperTools();
            }
            const mockConnection = (_a = options.mockConnection) !== null && _a !== void 0 ? _a : false;
            const connection = new connection_1.NativeWindowIntegrationConnection(providerId, authorizedUuid, mockConnection, (_b = options.local) !== null && _b !== void 0 ? _b : false, (_c = options.rescueOnDisplayChange) !== null && _c !== void 0 ? _c : false, options.url);
            await connection.connect();
            calledThroughCreate = true;
            const client = new NativeWindowIntegrationClient(connection, options.configuration);
            calledThroughCreate = false;
            return client;
        }
        catch (error) {
            throw error;
        }
    }
}
exports.NativeWindowIntegrationClient = NativeWindowIntegrationClient;
_NativeWindowIntegrationClient_client = new WeakMap(), _NativeWindowIntegrationClient_configuration = new WeakMap();
//# sourceMappingURL=index.js.map